////////////////////////////////////////////////////////////////////////////////
// Big Apple Hot Dogs Main View
////////////////////////////////////////////////////////////////////////////////

//------------------------------------------------
// Constructor
//------------------------------------------------
bigapple.views.MainView = function() {
	this.init();
	return this;
};

bigapple.views.MainView.prototype = (function() {
	
	var _public = {
		//------------------------------------------------
		// Init
		//------------------------------------------------
		init:function() {
			_private.setup();
		}
	};
	
	var _private = {
		//------------------------------------------------
		// Variables
		//------------------------------------------------
		BACKGROUND_HEIGHT: 664,
		sectionNav: null,
		styledMap: null,
		backgrounds: [],
		foregrounds: [],
		windowHeight: 0,
		
		//------------------------------------------------
		// Set up view
		//------------------------------------------------
		setup:function() {
			this.createSectionNav();
			this.getReferences();
			this.createListeners();
			this.resizeSections();
			this.prepContent();
		},
		
		//------------------------------------------------
		// Create section navigation
		//------------------------------------------------
		createSectionNav:function() {
			this.sectionNav = new bigapple.views.main.SectionNav();
			this.styledMap = new bigapple.views.main.StyledMap();
		},
		
		//------------------------------------------------
		// Store jQuery objects for each background
		//------------------------------------------------
		getReferences:function() {
			this.backgrounds = $('.section:not(:eq(0))');
			this.foregrounds = $('.section .foreground');
		},
		
		//------------------------------------------------
		// Check if user is using a mobile device
		//------------------------------------------------
		checkForMobiles:function() {
			return ((navigator.userAgent.match(/iPhone/i)) || (navigator.userAgent.match(/iPod/i)) || (navigator.userAgent.match(/iPad/i)) || (navigator.userAgent.match(/Android/i)) || (navigator.userAgent.match(/Windows Phone/i)) || (navigator.userAgent.match(/WebOS/i)));
		},
		
		//------------------------------------------------
		// Listen for events
		//------------------------------------------------
		createListeners:function() {
			$(window).bind("resize", function() {_private.onBrowserResized();});
			if (!this.checkForMobiles()) {
				$(window).bind("scroll", function() {_private.onBrowserScrolled();});
			}
		},
		
		//------------------------------------------------
		// Resize each section to match browser width/height
		//------------------------------------------------
		resizeSections:function() {
			$('.section').each(function() {
				$(this).css("height", $(window).height());
			});
			$('.section .foreground').each(function() {
				$(this).css("height", $(window).height());
			});
			this.windowHeight = $(window).height();
		},
		
		//------------------------------------------------
		// Adjust content for smooth scrolling
		//------------------------------------------------
		prepContent:function() {
			if (!this.checkForMobiles()) {
				$('#site').css("position", "fixed");
				var totalHeight = $('.section').length * this.windowHeight;
				$('body').append('<div id="site-height" style="height:' + totalHeight + 'px"></div>');
			} 
		},
		
		//------------------------------------------------
		// Adjust positions of backgrounds
		//------------------------------------------------
		adjustBackgrounds:function() {
			var scrollTop = $(window).scrollTop();
			$('#site').css("top", -scrollTop + "px");
			for (var i=0; i<this.backgrounds.length; i++) {
				var percentage = ((scrollTop - (i*this.windowHeight)) / this.windowHeight) - 1;
				var targetY = ((this.windowHeight/2) - (this.BACKGROUND_HEIGHT/2)) + (((550/2)) * percentage);
				$(this.backgrounds[i]).css("backgroundPosition", "50% " + targetY + "px");
				targetY = ((this.windowHeight/2) - (this.BACKGROUND_HEIGHT/2)) + (((850/2)) * percentage);
				$(this.foregrounds[i]).css("backgroundPosition", "50% " + targetY + "px");
			};
		},
		
		//------------------------------------------------
		// Recalculate site height
		//------------------------------------------------
		adjustSiteStructure:function() {
			var totalHeight = $('.section').length * this.windowHeight;
			$('#site-height').css("height", totalHeight + "px"); 
		},
		
		//------------------------------------------------
		// Resize required
		//------------------------------------------------
		onBrowserResized:function() {
			this.resizeSections();
			this.adjustSiteStructure();
		},
		
		//------------------------------------------------
		// Reposition backgrounds and foregrounds
		//------------------------------------------------
		onBrowserScrolled:function() {
			this.adjustBackgrounds();
		}
	};
	
	return _public;
}());